# -*- coding: utf-8 -*-
import datetime

from django.db.models import Q
from rest_framework import generics
from rest_framework.permissions import AllowAny

from thux.api.views import QuerysetMixin

from .. import models
from . import serializers


class NewsList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    now = datetime.datetime.now()
    queryset = models.News.objects.filter(
        status=1, categories__status=1,
    ).filter(
        Q(pub_date_begin__isnull=True) | Q(pub_date_begin__lte=now),
        Q(pub_date_end__isnull=True) | Q(pub_date_end__gte=now)
    ).distinct()
    serializer_class = serializers.NewsSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(NewsList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class NewsRetrieve(generics.RetrieveAPIView):
    permission_classes = (AllowAny,)
    now = datetime.datetime.now()
    queryset = models.News.objects.filter(
        status=1, categories__status=1,
    ).filter(
        Q(pub_date_begin__isnull=True) | Q(pub_date_begin__lte=now),
        Q(pub_date_end__isnull=True) | Q(pub_date_end__gte=now)
    ).distinct()
    serializer_class = serializers.NewsSerializer
    lookup_field = 'slug'
